
/** this files produces all the regression results for the CZ aggregate regressions in Tables 1, 2, 5, 6 and 7
of the paper Basso and peri (2015) ***/

clear all
set scheme s1mono
set matsize 11000
set more off
cap log close

cd C:\Users\gperi\Dropbox\Giovanni_MigrationConference2015\Basso_Peri_Chapter_1

log using output\logs\reg_aggregate_CZ.txt, text replace

disp "DateTime: $S_DATE $S_TIME"

/* *******************************************************************
 Regressions with CZ-aggregated dataset 
 
 Created on 1/8/2015 by Gaetano Basso (gbasso@ucdavis.edu)
 revised on 9/15/2015 by Giovanni Peri
******************************************************************* */

use data/aggregated_czone.dta, clear
sort czone survey
xtset czone decade

/** Regressions in Table 1, Column (1) ***/

**row (1)
xi: reg dlweekly d_immi_std i.survey [aw=l.population] if survey>=1980, vce(cluster czone)
***row (2)
xi: reg dlweekly d_immi_std i.survey i.czone [aw=l.population]if survey>=1980, vce(cluster czone)
** row (3) **
reg dlweekly d_immi_std i.survey i.czone[aw=l.population] if survey>=1990, vce(cluster czone)
** row (4)
reg dlweekly d_immi_std i.survey [aw=l.population] if survey==2010, vce(cluster czone)

centile population, centile(10 90)
** row(5) **
xi: reg dlweekly d_immi_std i.survey i.czone[aw=l.population]  if population>6100, vce(cluster czone)
** row (6) **
xi: reg dlweekly d_immi_std i.survey i.czone[aw=l.population]  if population<354000, vce(cluster czone)

/**********************/

/***Regressions in Table 2, Column (1) ***/

** row (1)
xi: reg dnnative d_immi_std i.survey [aw=l.population] , vce(cluster czone) 
**row(2)
xi: reg dnnative d_immi_std i.survey i.czone [aw=l.population] , vce(cluster czone)
** row (3) **
reg dnnative d_immi_std i.survey i.czone[aw=l.population] if survey>=1990, vce(cluster czone)
** row (4)
reg dnnative d_immi_std i.survey [aw=l.population] if survey==2010, vce(cluster czone)
** row(5) **
xi: reg dnnative d_immi_std i.survey i.czone[aw=l.population]  if population>6100, vce(cluster czone)
** row (6) **
xi: reg dnnative d_immi_std i.survey i.czone[aw=l.population]  if population<354000, vce(cluster czone)

/**********************/


*** Regressions in Table 5, column (1)

**** HIGH SCHOOL OR LESS*****
**row (1) **
xi: reg dlweekly_lskill d_immi_std i.survey [aw=l.population] if survey>=1980, vce(cluster czone)
** row (2) **
xi: reg dlweekly_lskill d_immi_std i.survey i.czone [aw=l.population]if survey>=1980, vce(cluster czone)
**row (3) **
reg dlweekly_lskill d_immi_std [aw=l.population] if survey==2010, vce(cluster czone)

***COLLEGE OR MORE ***
*** row (4)
xi: reg dlweekly_hskill d_immi_std i.survey [aw=l.population] if survey>=1980, vce(cluster czone)
*** row (5)
xi: reg dlweekly_hskill d_immi_std i.survey i.czone [aw=l.population]if survey>=1980, vce(cluster czone)
*** row (6)
reg dlweekly_hskill d_immi_std [aw=l.population] if survey==2010, vce(cluster czone)


/**********************/

/** Regressions in Table 6 ***/

**Row (1), Column (1)
xi: reg dlweekly d_immi_std dbartikwage i.survey  [aw=l.population] if survey>=1980, vce(cluster czone)
** Row (1), Column (2)
xi: reg dlweekly_lskill d_immi_std dbartikwage i.survey  [aw=l.population] if survey>=1980, vce(cluster czone)
**Row (1), Column (3)
xi: reg dlweekly_hskill d_immi_std dbartikwage i.survey  [aw=l.population] if survey>=1980, vce(cluster czone)

**Row(2), Column (1)
xi: reg dlweekly d_immi_std dbartikwage i.survey i.czone  [aw=l.population]if survey>=1980, vce(cluster czone)
**Row (2), Column (2)
xi: reg dlweekly_lskill d_immi_std dbartikwage i.survey i.czone  [aw=l.population]if survey>=1980, vce(cluster czone)
**Row (2) column (3)
xi: reg dlweekly_hskill d_immi_std dbartikwage i.survey i.czone  [aw=l.population]if survey>=1980, vce(cluster czone)

***Construct the instrumental variable

gen d_enclave_1_1970=(foreignhat_b1970-l.foreignhat_b1970)/(l.foreignhat_b1970+l.pnative) if survey>=1980
gen d_enclave_1_1980=(foreignhat_b1980-l.foreignhat_b1980)/(l.foreignhat_b1980+l.pnative) if survey>=1990


**regression in Table 7 ***
*** first stage ****
**row 1**
xi: reg d_immi_std d_enclave_1_1970 i.survey  [aw=l.population] if survey>=1990, vce(cluster czone)
test d_enclave_1_1970
**row 2**
xi: reg d_immi_std d_enclave_1_1980 i.survey  [aw=l.population] if survey>=1990, vce(cluster czone)
test d_enclave_1_1980

**** second stage
** row (1)
xi: ivreg dlweekly (d_immi_std= d_enclave_1_1970) i.survey [aw=l.population]  if survey>=1990, robust cluster(czone)
xi: ivreg dlweekly_lskill (d_immi_std= d_enclave_1_1970)  i.survey [aw=l.population]  if survey>=1990, robust cluster(czone)
xi: ivreg dlweekly_hskill (d_immi_std= d_enclave_1_1970) i.survey [aw=l.population]   if survey>=1990, robust cluster(czone)

** row (2)
xi: ivreg dlweekly (d_immi_std= d_enclave_1_1980) i.survey  [aw=l.population] if survey>=1990, robust cluster(czone)
xi: ivreg dlweekly_lskill (d_immi_std= d_enclave_1_1980)  i.survey [aw=l.population]  if survey>=1990, robust cluster(czone)
xi: ivreg dlweekly_hskill (d_immi_std= d_enclave_1_1980) i.survey [aw=l.population]   if survey>=1990, robust cluster(czone)



log close
