/** this files produces all the regression results for the CZ cell level regressions in Tables 3 and 4 of the paper Basso and peri (2015) ***/

clear all
set scheme s1mono
set matsize 11000
set maxvar 20000
set more off
cap log close

cd \\tsclient\c\Users\bassog.AD3\Dropbox\Giovanni_MigrationConference2015\Basso_Peri_Chapter_1

log using output\logs\reg_cell_CZ.txt, text replace

disp "DateTime: $S_DATE $S_TIME"

/* *******************************************************************
 Regressions with CZ-cell level dataset 
 
 Created on 1/8/2015 by Gaetano Basso (gbasso@ucdavis.edu)
 Revised on 9/16/2015 by Gaetano Basso
******************************************************************* */


use data\byEducExp_czone.dta, clear
sort czone edcode expcode survey

gen skills=10*edcode+expcode
gen panel=100*czone+10*edcode+expcode
gen zontim=100*czone+survey
gen skillsur=survey*100+skills
qui tab skillsur, gen(sksu)
qui tab survey, gen(srv)
qui tab zontim,gen(zt)

xtset panel survey, delta(10)

/** Dep and independent variables ***/
generate dlweekly=d.lweekly if survey>1970
generate d_nnative=(d.nnative)/(l.pimmig+l.pnative) if survey>1970
generate d_immi_std=(d.pimmig)/(l.pimmig+l.pnative) if survey>1970


/** Regressions in Table 3, Column (1) ***/
* Note: the variable summweight is the population of the cell

** row (1)
xi: reg dlweekly d_immi_std i.survey i.skills i.czone [aw=l.sumweight] if survey>1970, vce(cluster czone)
** row (2)
areg dlweekly d_immi_std srv* [aw=l.sumweight] if survey>1970, absorb(panel) vce(cluster czone)
** row (3)
areg dlweekly d_immi_std sksu* [aw=l.sumweight]  if survey>1970, absorb(panel) vce(cluster czone)
** row (4)
areg dlweekly d_immi_std sksu* zt* [aw=l.sumweight] if survey>1970, absorb(panel) vce(cluster czone)
** row (5)
areg dlweekly d_immi_std sksu*  [aw=l.sumweight] if survey>1980, absorb(panel) vce(cluster czone)

/** Regressions in Table 4, Column (1) ***/

** row (1)
xi: reg d_nnative d_immi_std i.survey i.skills i.czone [aw=l.sumweight] if survey>1970, vce(cluster czone)
** row (2)
areg d_nnative d_immi_std srv* [aw=l.sumweight] if survey>1970, absorb(panel) vce(cluster czone)
** row (3)
areg d_nnative d_immi_std sksu* [aw=l.sumweight] if survey>1970, absorb(panel) vce(cluster czone)
** row (4)
areg d_nnative d_immi_std sksu* zt* [aw=l.sumweight] if survey>1970, absorb(panel) vce(cluster czone)
** row (5)
areg d_nnative d_immi_std sksu*  [aw=l.sumweight] if survey>1980, absorb(panel) vce(cluster czone)


log close
